diff --git a/common/djangoapps/util/request_rate_limiter.py b/common/djangoapps/util/request_rate_limiter.py
index 384ac28276935d6742c62a4b594484e42bc57383..76ed9379932378ce81eaf580b5f7b2ebc9438313 100644
--- a/common/djangoapps/util/request_rate_limiter.py
+++ b/common/djangoapps/util/request_rate_limiter.py
@@ -101,3 +101,11 @@ class PasswordResetEmailRateLimiter(RequestRateLimiter):
         """
         for key in self.keys_to_check(request):
             self.cache_incr(key)
+
+
+class LoginAndRegisterRateLimiter(RequestRateLimiter):
+    """
+    Rate limiting backend for login and register endpoint which
+    allows 50 requests per IP for every 5 minutes.
+    """
+    requests = 50
diff --git a/openedx/core/djangoapps/user_authn/views/login_form.py b/openedx/core/djangoapps/user_authn/views/login_form.py
index 1322d2eb44120fbb0b67271ad0fa116326ef3510..16e61aab2914141f660b86d0d44a3a43e0a1bb52 100644
--- a/openedx/core/djangoapps/user_authn/views/login_form.py
+++ b/openedx/core/djangoapps/user_authn/views/login_form.py
@@ -35,7 +35,7 @@ from student.helpers import get_next_url_for_login_page
 from third_party_auth import pipeline
 from third_party_auth.decorators import xframe_allow_whitelisted
 from util.password_policy_validators import DEFAULT_MAX_PASSWORD_LENGTH
-from util.request_rate_limiter import BadRequestRateLimiter
+from util.request_rate_limiter import LoginAndRegisterRateLimiter
 
 log = logging.getLogger(__name__)
 
@@ -138,7 +138,7 @@ def login_and_registration_form(request, initial_mode="login"):
 
     """
 
-    limiter = BadRequestRateLimiter()
+    limiter = LoginAndRegisterRateLimiter()
     if limiter.is_rate_limit_exceeded(request):
         log.warning("Rate limit exceeded in login and registration with initial mode [%s]", initial_mode)
         return HttpResponseForbidden("Rate limit exceeded")
diff --git a/openedx/core/djangoapps/user_authn/views/tests/test_logistration.py b/openedx/core/djangoapps/user_authn/views/tests/test_logistration.py
index 3c0d4881185351ba737b17ff12dfbe29231df859..3e83c94015f4b683ed193622190eb47bfce49e00 100644
--- a/openedx/core/djangoapps/user_authn/views/tests/test_logistration.py
+++ b/openedx/core/djangoapps/user_authn/views/tests/test_logistration.py
@@ -75,10 +75,10 @@ class LoginAndRegistrationTest(ThirdPartyAuthTestMixin, UrlResetMixin, ModuleSto
 
     def test_login_and_registration_form_ratelimited(self):
         """
         Test that login enpoint allow only 30 requests for every 5 minutes.
         """
         login_url = reverse('signin_user')
-        for i in range(30):
+        for i in range(50):
             response = self.client.get(login_url)
             self.assertEqual(response.status_code, 200)
@@ -75,10 +75,10 @@ class LoginAndRegistrationTest(ThirdPartyAuthTestMixin, UrlResetMixin, ModuleSto
     def test_login_and_registration_form_ratelimited(self):
         """
-        Test that login enpoint allow only 30 requests for every 5 minutes.
+        Test that login enpoint allow only 50 requests for every 5 minutes.
         """
         login_url = reverse('signin_user')